==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/TriangulationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { TriangulationDataSourceDescription } from "./TriangulationDataSourceDescription";
/**
 * @hidden
 */
export let TriangulationDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class TriangulationDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (TriangulationDataSourceDescriptionMetadata.a == null) {
                TriangulationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TriangulationDataSourceDescriptionMetadata.c(TriangulationDataSourceDescriptionMetadata.a);
            }
            if (a.j(TriangulationDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.y(TriangulationDataSourceDescriptionMetadata.a);
            AsyncCompletedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("ImportCompletedRef", "EventRef::importCompleted");
        }
        static d(a) {
            TriangulationDataSourceDescriptionMetadata.b(a);
            a.aa("TriangulationDataSource", () => new TriangulationDataSourceDescription());
            a.z("TriangulationDataSource", TriangulationDataSourceDescriptionMetadata.a);
        }
    }
    TriangulationDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(TriangulationDataSourceDescriptionMetadata, 'TriangulationDataSourceDescriptionMetadata');
    TriangulationDataSourceDescriptionMetadata.a = null;
    return TriangulationDataSourceDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TriangulationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { TriangulationDataSourceDescription } from "./TriangulationDataSourceDescription";
/**
 * @hidden
 */
export let TriangulationDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class TriangulationDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (TriangulationDataSourceDescriptionMetadata.a == null) {
                TriangulationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TriangulationDataSourceDescriptionMetadata.c(TriangulationDataSourceDescriptionMetadata.a);
            }
            if (a.k(TriangulationDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.aa(TriangulationDataSourceDescriptionMetadata.a);
            AsyncCompletedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("ImportCompletedRef", "EventRef::importCompleted");
        }
        static d(a) {
            TriangulationDataSourceDescriptionMetadata.b(a);
            a.ac("TriangulationDataSource", () => new TriangulationDataSourceDescription());
            a.ab("TriangulationDataSource", TriangulationDataSourceDescriptionMetadata.a);
        }
    }
    TriangulationDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(TriangulationDataSourceDescriptionMetadata, 'TriangulationDataSourceDescriptionMetadata');
    TriangulationDataSourceDescriptionMetadata.a = null;
    return TriangulationDataSourceDescriptionMetadata;
})();
